Changelog
=========

Release 0.8
-----------

Needs Django 1.6 or newer, in order to get rid of deprecation-warnings
on 1.7

Bugfix 0.7.3-0.7.4
------------------

Bugfix causes bug leads to bugfix causes version number mixup etc.

Force push!

Release 0.7.2
-------------

Support for Django 1.4+, dropped support for Django 1.3 and older

Bugfix 0.7.1
------------

Fix with generic class based views

Release 0.7
-----------

New app, countries

Better support for Django 1.5

Generic functional views replaced with generic class based views

Release 0.6
-----------

Docs

Release 0.5
-----------

Support for django-taggit in blog

Release 0.4
-----------

New app, chunks

Release 0.3.1
-------------

Install with setup.py now works ;)

Removed stuff that clashed with Django 1.3

Version 0.3
-----------

New app, activation

Converted from subversion to git

Version 0.2
-----------

From library to installable app

Version 0.1.7
-------------

blog support django-tagging

Version 0.1.6
-------------

New app, comments

Version 0.1.5
-------------

New app, faq

Version 0.1.4
-------------

Templatetags and filters

Version 0.1.3
-------------

New app, badges

Version 0.1.2
-------------

New app, uri

Version 0.1.1
-------------

New app, privmsg

Version 0.1
-----------

Entered version control
